@@ -1,14 +1,9 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
 import collections
 import logging
 
-import notmuch
-
 
 class Filter:
     message = 'No message specified for filter'
@@ -67,19 +62,19 @@ class Filter:
     def add_tags(self, message, *tags):
         if tags:
             self.log.debug('Adding tags %s to id:%s' % (', '.join(tags),
-                                                       message.get_message_id()))
+                                                        message.get_message_id()))
             self._add_tags[message.get_message_id()].update(tags)
 
     def remove_tags(self, message, *tags):
         if tags:
             filtered_tags = list(tags)
             self.log.debug('Removing tags %s from id:%s' % (', '.join(filtered_tags),
-                                                           message.get_message_id()))
+                                                            message.get_message_id()))
             self._remove_tags[message.get_message_id()].update(filtered_tags)
 
     def flush_tags(self, message):
         self.log.debug('Removing all tags from id:%s' %
-                      message.get_message_id())
+                       message.get_message_id())
         self._flush_tags.append(message.get_message_id())
 
     def commit(self, dry_run=True):
