@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
-import random
 import sys
 
-from .MailMover import MailMover
+from afew.MailMover import MailMover
 
 try:
     from .files import watch_for_new_files, quick_find_dirs_hack
@@ -29,7 +25,7 @@ def main(options, database, query_string):
                             quick_find_dirs_hack(database.db_path))
     elif options.move_mails:
         for maildir, rules in options.mail_move_rules.items():
-            mover = MailMover(options.mail_move_age, options.mail_move_rename, options.dry_run)
+            mover = MailMover(options.mail_move_age, options.mail_move_rename, options.dry_run, options.notmuch_args)
             mover.move(maildir, rules)
             mover.close()
     else:
